==> python-ceilometerclient-1.0.0.tar.gz: python-ceilometerclient-1.0.0/tests/v1/test_projects.py <==
# Copyright 2012 OpenStack LLC.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import unittest

import ceilometerclient.v1.meters
from tests import utils


fixtures = {
    '/v1/projects': {
        'GET': (
            {},
            {'projects': [
                'a',
                'b',
            ]},
        ),
    },
    '/v1/sources/source_b/projects': {
        'GET': (
            {},
            {'projects': [
                 'b',
            ]},
        ),
    },
}


class ProjectManagerTest(unittest.TestCase):

    def setUp(self):
        self.api = utils.FakeAPI(fixtures)
        self.mgr = ceilometerclient.v1.meters.ProjectManager(self.api)

    def test_list_all(self):
        projects = list(self.mgr.list())
        expect = [
            ('GET', '/v1/projects', {}, None),
        ]
        self.assertEqual(self.api.calls, expect)
        self.assertEqual(len(projects), 2)
        self.assertEqual(projects[0].project_id, 'a')
        self.assertEqual(projects[1].project_id, 'b')

    def test_list_by_source(self):
        projects = list(self.mgr.list(source='source_b'))
        expect = [
            ('GET', '/v1/sources/source_b/projects', {}, None),
        ]
        self.assertEqual(self.api.calls, expect)
        self.assertEqual(len(projects), 1)
        self.assertEqual(projects[0].project_id, 'b')

==> python-ceilometerclient-1.0.1.tar.gz: python-ceilometerclient-1.0.1/tests/v1/test_projects.py <==
# Copyright 2012 OpenStack LLC.
# All Rights Reserved.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

import ceilometerclient.v1.meters
from tests import utils


fixtures = {
    '/v1/projects': {
        'GET': (
            {},
            {'projects': [
                'a',
                'b',
            ]},
        ),
    },
    '/v1/sources/source_b/projects': {
        'GET': (
            {},
            {'projects': ['b']},
        ),
    },
}


class ProjectManagerTest(utils.BaseTestCase):

    def setUp(self):
        super(ProjectManagerTest, self).setUp()
        self.api = utils.FakeAPI(fixtures)
        self.mgr = ceilometerclient.v1.meters.ProjectManager(self.api)

    def test_list_all(self):
        projects = list(self.mgr.list())
        expect = [
            ('GET', '/v1/projects', {}, None),
        ]
        self.assertEqual(self.api.calls, expect)
        self.assertEqual(len(projects), 2)
        self.assertEqual(projects[0].project_id, 'a')
        self.assertEqual(projects[1].project_id, 'b')

    def test_list_by_source(self):
        projects = list(self.mgr.list(source='source_b'))
        expect = [
            ('GET', '/v1/sources/source_b/projects', {}, None),
        ]
        self.assertEqual(self.api.calls, expect)
        self.assertEqual(len(projects), 1)
        self.assertEqual(projects[0].project_id, 'b')
